
<font color="gold">请调用get_feature_info(data, table_name)函数</font>

data格式: 数组、字典、dataFrame、numpy.array、csv、excel（表格使用路径传入）

table_name格式: 字符串

### 说明: 

读取第一行/表头并输出 (一维数组直接输出)

- 第一行输出标签
- 第二行输出列名 (特征列名称)
- 第三行输出表名

### 输出格式: 
```text
[ALIOTH - INFO - FEATURE_NAME] 
[xxx,xxx,xxx]
xxx
```
